"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FeedPagination(google.protobuf.message.Message):
    """分页信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    IS_REFRESH_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """"""
    offset: builtins.str
    """"""
    is_refresh: builtins.bool
    """"""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        offset: builtins.str = ...,
        is_refresh: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_refresh", b"is_refresh", "offset", b"offset", "page_size", b"page_size"]) -> None: ...

global___FeedPagination = FeedPagination

@typing_extensions.final
class FeedPaginationReply(google.protobuf.message.Message):
    """分页信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_OFFSET_FIELD_NUMBER: builtins.int
    PREV_OFFSET_FIELD_NUMBER: builtins.int
    LAST_READ_OFFSET_FIELD_NUMBER: builtins.int
    next_offset: builtins.str
    """"""
    prev_offset: builtins.str
    """"""
    last_read_offset: builtins.str
    """"""
    def __init__(
        self,
        *,
        next_offset: builtins.str = ...,
        prev_offset: builtins.str = ...,
        last_read_offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_read_offset", b"last_read_offset", "next_offset", b"next_offset", "prev_offset", b"prev_offset"]) -> None: ...

global___FeedPaginationReply = FeedPaginationReply

@typing_extensions.final
class Pagination(google.protobuf.message.Message):
    """分页信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    NEXT_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """"""
    next: builtins.str
    """"""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        next: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next", b"next", "page_size", b"page_size"]) -> None: ...

global___Pagination = Pagination

@typing_extensions.final
class PaginationReply(google.protobuf.message.Message):
    """分页信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_FIELD_NUMBER: builtins.int
    PREV_FIELD_NUMBER: builtins.int
    next: builtins.str
    """"""
    prev: builtins.str
    """"""
    def __init__(
        self,
        *,
        next: builtins.str = ...,
        prev: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next", b"next", "prev", b"prev"]) -> None: ...

global___PaginationReply = PaginationReply



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.polymer.community.govern.v1 import govern_pb2 as bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2


class AntiHarassmentServiceStub(object):
    """反骚扰
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StoreAntiHarassmentSettings = channel.unary_unary(
                '/bilibili.polymer.app.govern.v1.AntiHarassmentService/StoreAntiHarassmentSettings',
                request_serializer=bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.StoreAntiHarassmentSettingsReq.SerializeToString,
                response_deserializer=bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.StoreAntiHarassmentSettingsRsp.FromString,
                )
        self.LoadAntiHarassmentSettings = channel.unary_unary(
                '/bilibili.polymer.app.govern.v1.AntiHarassmentService/LoadAntiHarassmentSettings',
                request_serializer=bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.LoadAntiHarassmentSettingsReq.SerializeToString,
                response_deserializer=bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.LoadAntiHarassmentSettingsRsp.FromString,
                )


class AntiHarassmentServiceServicer(object):
    """反骚扰
    """

    def StoreAntiHarassmentSettings(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadAntiHarassmentSettings(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AntiHarassmentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StoreAntiHarassmentSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreAntiHarassmentSettings,
                    request_deserializer=bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.StoreAntiHarassmentSettingsReq.FromString,
                    response_serializer=bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.StoreAntiHarassmentSettingsRsp.SerializeToString,
            ),
            'LoadAntiHarassmentSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadAntiHarassmentSettings,
                    request_deserializer=bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.LoadAntiHarassmentSettingsReq.FromString,
                    response_serializer=bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.LoadAntiHarassmentSettingsRsp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.polymer.app.govern.v1.AntiHarassmentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AntiHarassmentService(object):
    """反骚扰
    """

    @staticmethod
    def StoreAntiHarassmentSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.polymer.app.govern.v1.AntiHarassmentService/StoreAntiHarassmentSettings',
            bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.StoreAntiHarassmentSettingsReq.SerializeToString,
            bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.StoreAntiHarassmentSettingsRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadAntiHarassmentSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.polymer.app.govern.v1.AntiHarassmentService/LoadAntiHarassmentSettings',
            bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.LoadAntiHarassmentSettingsReq.SerializeToString,
            bilibili_dot_polymer_dot_community_dot_govern_dot_v1_dot_govern__pb2.LoadAntiHarassmentSettingsRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from functools import wraps
from typing import Any, List, Optional, Tuple

import grpc
from google.protobuf.json_format import MessageToDict
from grpc import RpcError

from ..._typing import T_Auth
from ...exceptions import GrpcError
from ..protos.bilibili.rpc.status_pb2 import Status
from .metadata import make_metadata

# _channel = None


# async def get_channel():
#     global _channel
#     if _channel is None or _channel.get_state() == grpc.ChannelConnectivity.SHUTDOWN:
#         _channel = grpc.aio.secure_channel(
#             "grpc.biliapi.net",
#             grpc.ssl_channel_credentials(),
#             options=[("grpc.keepalive_time_ms", 10000)],
#         )
#     return _channel


def grpc_request(func):
    @wraps(func)
    async def wrapper(
        *args,
        proxy=None,
        auth: T_Auth = None,
        access_key: Optional[str] = None,
        timeout: int = 10,
        to_dict: bool = False,
        **kwargs
    ):
        options: List[Tuple[str, Any]] = [
            # ("grpc.keepalive_timeout_ms", 10000),
            ("grpc.http_proxy", proxy or ""),
        ]
        async with grpc.aio.secure_channel(
            "grpc.biliapi.net",
            grpc.ssl_channel_credentials(),
            options=options,
        ) as channel:
            try:
                result = await func(
                    *args,
                    _channel=channel,
                    metadata=make_metadata(auth, access_key),
                    timeout=timeout,
                    **kwargs
                )
                if to_dict:
                    result = MessageToDict(result)
                return result
            except RpcError as e:
                status = e.trailing_metadata().get(  # type: ignore
                    "grpc-status-details-bin"
                )
                if not status:
                    raise
                status_dict = MessageToDict(Status.FromString(status))
                if status_dict["code"] == 2:
                    raise GrpcError(
                        status_dict["details"][0]["code"],
                        status_dict["details"][0]["message"],
                    )
                else:
                    raise GrpcError(status_dict["code"], status_dict["message"])

    return wrapper



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.broadcast.v1 import test_pb2 as bilibili_dot_broadcast_dot_v1_dot_test__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class TestStub(object):
    """服务端下发的测试专用消息，客户端debug/release包都会通过弹窗响应该消息
    后端平台 必须 限制该消息只能针对单个用户发送

    Test
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WatchTestEvent = channel.unary_stream(
                '/bilibili.broadcast.v1.Test/WatchTestEvent',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bilibili_dot_broadcast_dot_v1_dot_test__pb2.TestResp.FromString,
                )


class TestServicer(object):
    """服务端下发的测试专用消息，客户端debug/release包都会通过弹窗响应该消息
    后端平台 必须 限制该消息只能针对单个用户发送

    Test
    """

    def WatchTestEvent(self, request, context):
        """监听上报事件
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TestServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WatchTestEvent': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchTestEvent,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bilibili_dot_broadcast_dot_v1_dot_test__pb2.TestResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.broadcast.v1.Test', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Test(object):
    """服务端下发的测试专用消息，客户端debug/release包都会通过弹窗响应该消息
    后端平台 必须 限制该消息只能针对单个用户发送

    Test
    """

    @staticmethod
    def WatchTestEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/bilibili.broadcast.v1.Test/WatchTestEvent',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bilibili_dot_broadcast_dot_v1_dot_test__pb2.TestResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class Test2Stub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Test = channel.unary_unary(
                '/bilibili.broadcast.v1.Test2/Test',
                request_serializer=bilibili_dot_broadcast_dot_v1_dot_test__pb2.AddParams.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class Test2Servicer(object):
    """
    """

    def Test(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_Test2Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Test': grpc.unary_unary_rpc_method_handler(
                    servicer.Test,
                    request_deserializer=bilibili_dot_broadcast_dot_v1_dot_test__pb2.AddParams.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.broadcast.v1.Test2', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Test2(object):
    """
    """

    @staticmethod
    def Test(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.broadcast.v1.Test2/Test',
            bilibili_dot_broadcast_dot_v1_dot_test__pb2.AddParams.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Chronos(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MD5_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    md5: builtins.str
    """"""
    file: builtins.str
    """"""
    sign: builtins.str
    """"""
    def __init__(
        self,
        *,
        md5: builtins.str = ...,
        file: builtins.str = ...,
        sign: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "md5", b"md5", "sign", b"sign"]) -> None: ...

global___Chronos = Chronos

@typing_extensions.final
class CommandDm(google.protobuf.message.Message):
    """互动弹幕条目信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    IDSTR_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕id"""
    oid: builtins.int
    """对象视频cid"""
    mid: builtins.str
    """发送者mid"""
    command: builtins.str
    """互动弹幕指令"""
    content: builtins.str
    """互动弹幕正文"""
    progress: builtins.int
    """出现时间"""
    ctime: builtins.str
    """创建时间"""
    mtime: builtins.str
    """发布时间"""
    extra: builtins.str
    """扩展json数据"""
    idStr: builtins.str
    """弹幕id str类型"""
    display: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.str = ...,
        command: builtins.str = ...,
        content: builtins.str = ...,
        progress: builtins.int = ...,
        ctime: builtins.str = ...,
        mtime: builtins.str = ...,
        extra: builtins.str = ...,
        idStr: builtins.str = ...,
        display: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "content", b"content", "ctime", b"ctime", "display", b"display", "extra", b"extra", "id", b"id", "idStr", b"idStr", "mid", b"mid", "mtime", b"mtime", "oid", b"oid", "progress", b"progress"]) -> None: ...

global___CommandDm = CommandDm

@typing_extensions.final
class CommandDmOtt(google.protobuf.message.Message):
    """ott互动弹幕条目信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕id"""
    oid: builtins.int
    """对象视频cid"""
    mid: builtins.int
    """发送者mid"""
    type: builtins.int
    """"""
    command: builtins.str
    """互动弹幕指令"""
    content: builtins.str
    """互动弹幕正文"""
    state: builtins.int
    """"""
    progress: builtins.int
    """出现时间"""
    ctime: builtins.str
    """创建时间"""
    mtime: builtins.str
    """发布时间"""
    extra: builtins.str
    """扩展json数据"""
    id_str: builtins.str
    """弹幕id str类型"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        type: builtins.int = ...,
        command: builtins.str = ...,
        content: builtins.str = ...,
        state: builtins.int = ...,
        progress: builtins.int = ...,
        ctime: builtins.str = ...,
        mtime: builtins.str = ...,
        extra: builtins.str = ...,
        id_str: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "content", b"content", "ctime", b"ctime", "extra", b"extra", "id", b"id", "id_str", b"id_str", "mid", b"mid", "mtime", b"mtime", "oid", b"oid", "progress", b"progress", "state", b"state", "type", b"type"]) -> None: ...

global___CommandDmOtt = CommandDmOtt

@typing_extensions.final
class CommandDmsOttReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_DMS_OTT_FIELD_NUMBER: builtins.int
    @property
    def command_dms_ott(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandDmOtt]:
        """"""
    def __init__(
        self,
        *,
        command_dms_ott: collections.abc.Iterable[global___CommandDmOtt] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command_dms_ott", b"command_dms_ott"]) -> None: ...

global___CommandDmsOttReply = CommandDmsOttReply

@typing_extensions.final
class CommandDmsOttReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "mid", b"mid"]) -> None: ...

global___CommandDmsOttReq = CommandDmsOttReq

@typing_extensions.final
class DanmakuAIFlag(google.protobuf.message.Message):
    """弹幕ai云屏蔽列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DM_FLAGS_FIELD_NUMBER: builtins.int
    @property
    def dm_flags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuFlag]:
        """弹幕ai云屏蔽条目"""
    def __init__(
        self,
        *,
        dm_flags: collections.abc.Iterable[global___DanmakuFlag] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dm_flags", b"dm_flags"]) -> None: ...

global___DanmakuAIFlag = DanmakuAIFlag

@typing_extensions.final
class DanmakuElem(google.protobuf.message.Message):
    """弹幕条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    FONTSIZE_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    MIDHASH_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    IDSTR_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕dmid"""
    progress: builtins.int
    """弹幕出现位置(单位ms)"""
    mode: builtins.int
    """弹幕类型"""
    fontsize: builtins.int
    """弹幕字号"""
    color: builtins.int
    """弹幕颜色"""
    midHash: builtins.str
    """发送着mid hash"""
    content: builtins.str
    """弹幕正文"""
    ctime: builtins.int
    """发送时间"""
    weight: builtins.int
    """权重 区间:[1,10]"""
    action: builtins.str
    """动作"""
    pool: builtins.int
    """弹幕池"""
    idStr: builtins.str
    """弹幕dmid str"""
    attr: builtins.int
    """弹幕属性位(bin求AND)
    bit0:保护 bit1:直播 bit2:高赞
    """
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        progress: builtins.int = ...,
        mode: builtins.int = ...,
        fontsize: builtins.int = ...,
        color: builtins.int = ...,
        midHash: builtins.str = ...,
        content: builtins.str = ...,
        ctime: builtins.int = ...,
        weight: builtins.int = ...,
        action: builtins.str = ...,
        pool: builtins.int = ...,
        idStr: builtins.str = ...,
        attr: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "attr", b"attr", "color", b"color", "content", b"content", "ctime", b"ctime", "fontsize", b"fontsize", "id", b"id", "idStr", b"idStr", "midHash", b"midHash", "mode", b"mode", "pool", b"pool", "progress", b"progress", "weight", b"weight"]) -> None: ...

global___DanmakuElem = DanmakuElem

@typing_extensions.final
class DanmakuFlag(google.protobuf.message.Message):
    """弹幕ai云屏蔽条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DMID_FIELD_NUMBER: builtins.int
    FLAG_FIELD_NUMBER: builtins.int
    dmid: builtins.int
    """弹幕dmid"""
    flag: builtins.int
    """评分"""
    def __init__(
        self,
        *,
        dmid: builtins.int = ...,
        flag: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dmid", b"dmid", "flag", b"flag"]) -> None: ...

global___DanmakuFlag = DanmakuFlag

@typing_extensions.final
class DanmakuFlagConfig(google.protobuf.message.Message):
    """云屏蔽配置信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REC_FLAG_FIELD_NUMBER: builtins.int
    REC_TEXT_FIELD_NUMBER: builtins.int
    REC_SWITCH_FIELD_NUMBER: builtins.int
    rec_flag: builtins.int
    """云屏蔽等级"""
    rec_text: builtins.str
    """云屏蔽文案"""
    rec_switch: builtins.int
    """云屏蔽开关"""
    def __init__(
        self,
        *,
        rec_flag: builtins.int = ...,
        rec_text: builtins.str = ...,
        rec_switch: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rec_flag", b"rec_flag", "rec_switch", b"rec_switch", "rec_text", b"rec_text"]) -> None: ...

global___DanmakuFlagConfig = DanmakuFlagConfig

@typing_extensions.final
class DanmuDefaultPlayerConfig(google.protobuf.message.Message):
    """弹幕默认配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_DANMAKU_USE_DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKTOP_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSCROLL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKBOTTOM_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKCOLORFUL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKREPEAT_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSPECIAL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_OPACITY_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SCALINGFACTOR_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SPEED_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SENIOR_MODE_SWITCH_FIELD_NUMBER: builtins.int
    player_danmaku_use_default_config: builtins.bool
    """是否使用推荐弹幕设置"""
    player_danmaku_ai_recommended_switch: builtins.bool
    """是否开启智能云屏蔽"""
    player_danmaku_ai_recommended_level: builtins.int
    """智能云屏蔽等级"""
    player_danmaku_blocktop: builtins.bool
    """是否屏蔽顶端弹幕"""
    player_danmaku_blockscroll: builtins.bool
    """是否屏蔽滚动弹幕"""
    player_danmaku_blockbottom: builtins.bool
    """是否屏蔽底端弹幕"""
    player_danmaku_blockcolorful: builtins.bool
    """是否屏蔽彩色弹幕"""
    player_danmaku_blockrepeat: builtins.bool
    """是否屏蔽重复弹幕"""
    player_danmaku_blockspecial: builtins.bool
    """是否屏蔽高级弹幕"""
    player_danmaku_opacity: builtins.float
    """弹幕不透明度"""
    player_danmaku_scalingfactor: builtins.float
    """弹幕缩放比例"""
    player_danmaku_domain: builtins.float
    """弹幕显示区域"""
    player_danmaku_speed: builtins.int
    """弹幕速度"""
    inline_player_danmaku_switch: builtins.bool
    """是否开启弹幕"""
    player_danmaku_senior_mode_switch: builtins.int
    """"""
    def __init__(
        self,
        *,
        player_danmaku_use_default_config: builtins.bool = ...,
        player_danmaku_ai_recommended_switch: builtins.bool = ...,
        player_danmaku_ai_recommended_level: builtins.int = ...,
        player_danmaku_blocktop: builtins.bool = ...,
        player_danmaku_blockscroll: builtins.bool = ...,
        player_danmaku_blockbottom: builtins.bool = ...,
        player_danmaku_blockcolorful: builtins.bool = ...,
        player_danmaku_blockrepeat: builtins.bool = ...,
        player_danmaku_blockspecial: builtins.bool = ...,
        player_danmaku_opacity: builtins.float = ...,
        player_danmaku_scalingfactor: builtins.float = ...,
        player_danmaku_domain: builtins.float = ...,
        player_danmaku_speed: builtins.int = ...,
        inline_player_danmaku_switch: builtins.bool = ...,
        player_danmaku_senior_mode_switch: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_player_danmaku_switch", b"inline_player_danmaku_switch", "player_danmaku_ai_recommended_level", b"player_danmaku_ai_recommended_level", "player_danmaku_ai_recommended_switch", b"player_danmaku_ai_recommended_switch", "player_danmaku_blockbottom", b"player_danmaku_blockbottom", "player_danmaku_blockcolorful", b"player_danmaku_blockcolorful", "player_danmaku_blockrepeat", b"player_danmaku_blockrepeat", "player_danmaku_blockscroll", b"player_danmaku_blockscroll", "player_danmaku_blockspecial", b"player_danmaku_blockspecial", "player_danmaku_blocktop", b"player_danmaku_blocktop", "player_danmaku_domain", b"player_danmaku_domain", "player_danmaku_opacity", b"player_danmaku_opacity", "player_danmaku_scalingfactor", b"player_danmaku_scalingfactor", "player_danmaku_senior_mode_switch", b"player_danmaku_senior_mode_switch", "player_danmaku_speed", b"player_danmaku_speed", "player_danmaku_use_default_config", b"player_danmaku_use_default_config"]) -> None: ...

global___DanmuDefaultPlayerConfig = DanmuDefaultPlayerConfig

@typing_extensions.final
class DanmuPlayerConfig(google.protobuf.message.Message):
    """弹幕配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SWITCH_SAVE_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_USE_DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKTOP_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSCROLL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKBOTTOM_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKCOLORFUL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKREPEAT_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSPECIAL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_OPACITY_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SCALINGFACTOR_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SPEED_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_ENABLEBLOCKLIST_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_IOS_SWITCH_SAVE_FIELD_NUMBER: builtins.int
    player_danmaku_switch: builtins.bool
    """是否开启弹幕"""
    player_danmaku_switch_save: builtins.bool
    """是否记录弹幕开关设置"""
    player_danmaku_use_default_config: builtins.bool
    """是否使用推荐弹幕设置"""
    player_danmaku_ai_recommended_switch: builtins.bool
    """是否开启智能云屏蔽"""
    player_danmaku_ai_recommended_level: builtins.int
    """智能云屏蔽等级"""
    player_danmaku_blocktop: builtins.bool
    """是否屏蔽顶端弹幕"""
    player_danmaku_blockscroll: builtins.bool
    """是否屏蔽滚动弹幕"""
    player_danmaku_blockbottom: builtins.bool
    """是否屏蔽底端弹幕"""
    player_danmaku_blockcolorful: builtins.bool
    """是否屏蔽彩色弹幕"""
    player_danmaku_blockrepeat: builtins.bool
    """是否屏蔽重复弹幕"""
    player_danmaku_blockspecial: builtins.bool
    """是否屏蔽高级弹幕"""
    player_danmaku_opacity: builtins.float
    """弹幕不透明度"""
    player_danmaku_scalingfactor: builtins.float
    """弹幕缩放比例"""
    player_danmaku_domain: builtins.float
    """弹幕显示区域"""
    player_danmaku_speed: builtins.int
    """弹幕速度"""
    player_danmaku_enableblocklist: builtins.bool
    """是否开启屏蔽列表"""
    inline_player_danmaku_switch: builtins.bool
    """是否开启弹幕"""
    inline_player_danmaku_config: builtins.int
    """"""
    player_danmaku_ios_switch_save: builtins.int
    """"""
    def __init__(
        self,
        *,
        player_danmaku_switch: builtins.bool = ...,
        player_danmaku_switch_save: builtins.bool = ...,
        player_danmaku_use_default_config: builtins.bool = ...,
        player_danmaku_ai_recommended_switch: builtins.bool = ...,
        player_danmaku_ai_recommended_level: builtins.int = ...,
        player_danmaku_blocktop: builtins.bool = ...,
        player_danmaku_blockscroll: builtins.bool = ...,
        player_danmaku_blockbottom: builtins.bool = ...,
        player_danmaku_blockcolorful: builtins.bool = ...,
        player_danmaku_blockrepeat: builtins.bool = ...,
        player_danmaku_blockspecial: builtins.bool = ...,
        player_danmaku_opacity: builtins.float = ...,
        player_danmaku_scalingfactor: builtins.float = ...,
        player_danmaku_domain: builtins.float = ...,
        player_danmaku_speed: builtins.int = ...,
        player_danmaku_enableblocklist: builtins.bool = ...,
        inline_player_danmaku_switch: builtins.bool = ...,
        inline_player_danmaku_config: builtins.int = ...,
        player_danmaku_ios_switch_save: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_player_danmaku_config", b"inline_player_danmaku_config", "inline_player_danmaku_switch", b"inline_player_danmaku_switch", "player_danmaku_ai_recommended_level", b"player_danmaku_ai_recommended_level", "player_danmaku_ai_recommended_switch", b"player_danmaku_ai_recommended_switch", "player_danmaku_blockbottom", b"player_danmaku_blockbottom", "player_danmaku_blockcolorful", b"player_danmaku_blockcolorful", "player_danmaku_blockrepeat", b"player_danmaku_blockrepeat", "player_danmaku_blockscroll", b"player_danmaku_blockscroll", "player_danmaku_blockspecial", b"player_danmaku_blockspecial", "player_danmaku_blocktop", b"player_danmaku_blocktop", "player_danmaku_domain", b"player_danmaku_domain", "player_danmaku_enableblocklist", b"player_danmaku_enableblocklist", "player_danmaku_ios_switch_save", b"player_danmaku_ios_switch_save", "player_danmaku_opacity", b"player_danmaku_opacity", "player_danmaku_scalingfactor", b"player_danmaku_scalingfactor", "player_danmaku_speed", b"player_danmaku_speed", "player_danmaku_switch", b"player_danmaku_switch", "player_danmaku_switch_save", b"player_danmaku_switch_save", "player_danmaku_use_default_config", b"player_danmaku_use_default_config"]) -> None: ...

global___DanmuPlayerConfig = DanmuPlayerConfig

@typing_extensions.final
class DanmuPlayerDynamicConfig(google.protobuf.message.Message):
    """弹幕显示区域自动配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRESS_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    progress: builtins.int
    """时间"""
    player_danmaku_domain: builtins.float
    """弹幕显示区域"""
    def __init__(
        self,
        *,
        progress: builtins.int = ...,
        player_danmaku_domain: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["player_danmaku_domain", b"player_danmaku_domain", "progress", b"progress"]) -> None: ...

global___DanmuPlayerDynamicConfig = DanmuPlayerDynamicConfig

@typing_extensions.final
class DanmuPlayerViewConfig(google.protobuf.message.Message):
    """弹幕配置信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DANMUKU_DEFAULT_PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    DANMUKU_PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    DANMUKU_PLAYER_DYNAMIC_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def danmuku_default_player_config(self) -> global___DanmuDefaultPlayerConfig:
        """弹幕默认配置"""
    @property
    def danmuku_player_config(self) -> global___DanmuPlayerConfig:
        """弹幕用户配置"""
    @property
    def danmuku_player_dynamic_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmuPlayerDynamicConfig]:
        """弹幕显示区域自动配置列表"""
    def __init__(
        self,
        *,
        danmuku_default_player_config: global___DanmuDefaultPlayerConfig | None = ...,
        danmuku_player_config: global___DanmuPlayerConfig | None = ...,
        danmuku_player_dynamic_config: collections.abc.Iterable[global___DanmuPlayerDynamicConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["danmuku_default_player_config", b"danmuku_default_player_config", "danmuku_player_config", b"danmuku_player_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["danmuku_default_player_config", b"danmuku_default_player_config", "danmuku_player_config", b"danmuku_player_config", "danmuku_player_dynamic_config", b"danmuku_player_dynamic_config"]) -> None: ...

global___DanmuPlayerViewConfig = DanmuPlayerViewConfig

@typing_extensions.final
class DmSegMobileReply(google.protobuf.message.Message):
    """获取弹幕-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELEMS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    AI_FLAG_FIELD_NUMBER: builtins.int
    @property
    def elems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuElem]:
        """弹幕列表"""
    state: builtins.int
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """
    @property
    def ai_flag(self) -> global___DanmakuAIFlag:
        """弹幕云屏蔽ai评分值"""
    def __init__(
        self,
        *,
        elems: collections.abc.Iterable[global___DanmakuElem] | None = ...,
        state: builtins.int = ...,
        ai_flag: global___DanmakuAIFlag | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_flag", b"ai_flag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_flag", b"ai_flag", "elems", b"elems", "state", b"state"]) -> None: ...

global___DmSegMobileReply = DmSegMobileReply

@typing_extensions.final
class DmSegMobileReq(google.protobuf.message.Message):
    """获取弹幕-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SEGMENT_INDEX_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """稿件avid/漫画epid"""
    oid: builtins.int
    """视频cid/漫画cid"""
    type: builtins.int
    """弹幕类型
    1:视频 2:漫画
    """
    segment_index: builtins.int
    """分段(6min)"""
    teenagers_mode: builtins.int
    """是否青少年模式"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        segment_index: builtins.int = ...,
        teenagers_mode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "oid", b"oid", "pid", b"pid", "segment_index", b"segment_index", "teenagers_mode", b"teenagers_mode", "type", b"type"]) -> None: ...

global___DmSegMobileReq = DmSegMobileReq

@typing_extensions.final
class DmViewReply(google.protobuf.message.Message):
    """客户端弹幕元数据-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOSED_FIELD_NUMBER: builtins.int
    MASK_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    SPECIAL_DMS_FIELD_NUMBER: builtins.int
    AI_FLAG_FIELD_NUMBER: builtins.int
    PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    SEND_BOX_STYLE_FIELD_NUMBER: builtins.int
    ALLOW_FIELD_NUMBER: builtins.int
    CHECK_BOX_FIELD_NUMBER: builtins.int
    CHECK_BOX_SHOW_MSG_FIELD_NUMBER: builtins.int
    TEXT_PLACEHOLDER_FIELD_NUMBER: builtins.int
    INPUT_PLACEHOLDER_FIELD_NUMBER: builtins.int
    COMMAND_CLOSE_FIELD_NUMBER: builtins.int
    closed: builtins.bool
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """
    @property
    def mask(self) -> global___VideoMask:
        """智能防挡弹幕蒙版信息"""
    @property
    def subtitle(self) -> global___VideoSubtitle:
        """视频字幕"""
    @property
    def special_dms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """高级弹幕专包url(bfs)"""
    @property
    def ai_flag(self) -> global___DanmakuFlagConfig:
        """云屏蔽配置信息"""
    @property
    def player_config(self) -> global___DanmuPlayerViewConfig:
        """弹幕配置信息"""
    send_box_style: builtins.int
    """弹幕发送框样式"""
    allow: builtins.bool
    """是否允许"""
    check_box: builtins.str
    """check box 是否展示"""
    check_box_show_msg: builtins.str
    """check box 展示文本"""
    text_placeholder: builtins.str
    """展示文案"""
    input_placeholder: builtins.str
    """弹幕输入框文案"""
    command_close: builtins.bool
    """"""
    def __init__(
        self,
        *,
        closed: builtins.bool = ...,
        mask: global___VideoMask | None = ...,
        subtitle: global___VideoSubtitle | None = ...,
        special_dms: collections.abc.Iterable[builtins.str] | None = ...,
        ai_flag: global___DanmakuFlagConfig | None = ...,
        player_config: global___DanmuPlayerViewConfig | None = ...,
        send_box_style: builtins.int = ...,
        allow: builtins.bool = ...,
        check_box: builtins.str = ...,
        check_box_show_msg: builtins.str = ...,
        text_placeholder: builtins.str = ...,
        input_placeholder: builtins.str = ...,
        command_close: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_flag", b"ai_flag", "mask", b"mask", "player_config", b"player_config", "subtitle", b"subtitle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_flag", b"ai_flag", "allow", b"allow", "check_box", b"check_box", "check_box_show_msg", b"check_box_show_msg", "closed", b"closed", "command_close", b"command_close", "input_placeholder", b"input_placeholder", "mask", b"mask", "player_config", b"player_config", "send_box_style", b"send_box_style", "special_dms", b"special_dms", "subtitle", b"subtitle", "text_placeholder", b"text_placeholder"]) -> None: ...

global___DmViewReply = DmViewReply

@typing_extensions.final
class DmViewReq(google.protobuf.message.Message):
    """客户端弹幕元数据-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    IS_HARD_BOOT_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """稿件avid/漫画epid"""
    oid: builtins.int
    """视频cid/漫画cid"""
    type: builtins.int
    """弹幕类型
    1:视频 2:漫画
    """
    spmid: builtins.str
    """页面spm"""
    is_hard_boot: builtins.int
    """是否冷启"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        spmid: builtins.str = ...,
        is_hard_boot: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "is_hard_boot", b"is_hard_boot", "oid", b"oid", "pid", b"pid", "spmid", b"spmid", "type", b"type"]) -> None: ...

global___DmViewReq = DmViewReq

@typing_extensions.final
class SubtitleItem(google.protobuf.message.Message):
    """单个字幕信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    LAN_FIELD_NUMBER: builtins.int
    LAN_DOC_FIELD_NUMBER: builtins.int
    SUBTITLE_URL_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """字幕id"""
    id_str: builtins.str
    """字幕id str"""
    lan: builtins.str
    """字幕语言代码"""
    lan_doc: builtins.str
    """字幕语言"""
    subtitle_url: builtins.str
    """字幕文件url"""
    @property
    def author(self) -> global___UserInfo:
        """字幕作者信息"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        id_str: builtins.str = ...,
        lan: builtins.str = ...,
        lan_doc: builtins.str = ...,
        subtitle_url: builtins.str = ...,
        author: global___UserInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "id", b"id", "id_str", b"id_str", "lan", b"lan", "lan_doc", b"lan_doc", "subtitle_url", b"subtitle_url"]) -> None: ...

global___SubtitleItem = SubtitleItem

@typing_extensions.final
class TvViewProgressReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_GUIDE_FIELD_NUMBER: builtins.int
    CHRONOS_FIELD_NUMBER: builtins.int
    @property
    def video_guide(self) -> global___VideoGuide:
        """"""
    @property
    def chronos(self) -> global___Chronos:
        """"""
    def __init__(
        self,
        *,
        video_guide: global___VideoGuide | None = ...,
        chronos: global___Chronos | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chronos", b"chronos", "video_guide", b"video_guide"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chronos", b"chronos", "video_guide", b"video_guide"]) -> None: ...

global___TvViewProgressReply = TvViewProgressReply

@typing_extensions.final
class TvViewProgressReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_PROTOCOL_FIELD_NUMBER: builtins.int
    SERVICE_KEY_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    GUEST_ACCESS_KEY_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    up_mid: builtins.int
    """"""
    engine_version: builtins.str
    """"""
    message_protocol: builtins.str
    """"""
    service_key: builtins.str
    """"""
    sid: builtins.int
    """"""
    pid: builtins.int
    """"""
    guest_access_key: builtins.str
    """"""
    epid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        up_mid: builtins.int = ...,
        engine_version: builtins.str = ...,
        message_protocol: builtins.str = ...,
        service_key: builtins.str = ...,
        sid: builtins.int = ...,
        pid: builtins.int = ...,
        guest_access_key: builtins.str = ...,
        epid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "engine_version", b"engine_version", "epid", b"epid", "from", b"from", "guest_access_key", b"guest_access_key", "message_protocol", b"message_protocol", "pid", b"pid", "service_key", b"service_key", "sid", b"sid", "up_mid", b"up_mid"]) -> None: ...

global___TvViewProgressReq = TvViewProgressReq

@typing_extensions.final
class UserInfo(google.protobuf.message.Message):
    """字幕作者信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    name: builtins.str
    """用户昵称"""
    sex: builtins.str
    """用户性别"""
    face: builtins.str
    """用户头像url"""
    sign: builtins.str
    """用户签名"""
    rank: builtins.int
    """用户等级"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        sex: builtins.str = ...,
        face: builtins.str = ...,
        sign: builtins.str = ...,
        rank: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "mid", b"mid", "name", b"name", "rank", b"rank", "sex", b"sex", "sign", b"sign"]) -> None: ...

global___UserInfo = UserInfo

@typing_extensions.final
class VideoGuide(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_DMS_FIELD_NUMBER: builtins.int
    @property
    def command_dms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandDm]:
        """"""
    def __init__(
        self,
        *,
        command_dms: collections.abc.Iterable[global___CommandDm] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command_dms", b"command_dms"]) -> None: ...

global___VideoGuide = VideoGuide

@typing_extensions.final
class VideoMask(google.protobuf.message.Message):
    """智能防挡弹幕蒙版信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    PLAT_FIELD_NUMBER: builtins.int
    FPS_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    MASK_URL_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """视频cid"""
    plat: builtins.int
    """平台
    0:web端 1:客户端
    """
    fps: builtins.int
    """帧率"""
    time: builtins.int
    """间隔时间"""
    mask_url: builtins.str
    """蒙版url"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
        plat: builtins.int = ...,
        fps: builtins.int = ...,
        time: builtins.int = ...,
        mask_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "fps", b"fps", "mask_url", b"mask_url", "plat", b"plat", "time", b"time"]) -> None: ...

global___VideoMask = VideoMask

@typing_extensions.final
class VideoSubtitle(google.protobuf.message.Message):
    """视频字幕信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAN_FIELD_NUMBER: builtins.int
    LANDOC_FIELD_NUMBER: builtins.int
    SUBTITLES_FIELD_NUMBER: builtins.int
    lan: builtins.str
    """视频原语言代码"""
    lanDoc: builtins.str
    """视频原语言"""
    @property
    def subtitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubtitleItem]:
        """视频字幕列表"""
    def __init__(
        self,
        *,
        lan: builtins.str = ...,
        lanDoc: builtins.str = ...,
        subtitles: collections.abc.Iterable[global___SubtitleItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lan", b"lan", "lanDoc", b"lanDoc", "subtitles", b"subtitles"]) -> None: ...

global___VideoSubtitle = VideoSubtitle



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/show/rank/v1/rank.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$bilibili/app/show/rank/v1/rank.proto\x12\x14\x62ilibili.app.show.v1\"\x8f\x04\n\x04Item\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\r\n\x05param\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x14\n\x0credirect_url\x18\x05 \x01(\t\x12\x0c\n\x04goto\x18\x06 \x01(\t\x12\x0c\n\x04play\x18\x07 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x08 \x01(\x05\x12\x0b\n\x03mid\x18\t \x01(\x03\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x0b \x01(\t\x12\r\n\x05reply\x18\x0c \x01(\x05\x12\x11\n\tfavourite\x18\r \x01(\x05\x12\x10\n\x08pub_date\x18\x0e \x01(\x03\x12\x0b\n\x03rid\x18\x0f \x01(\x05\x12\r\n\x05rname\x18\x10 \x01(\t\x12\x10\n\x08\x64uration\x18\x11 \x01(\x03\x12\x0c\n\x04like\x18\x12 \x01(\x05\x12\x0b\n\x03\x63id\x18\x13 \x01(\x03\x12\x0b\n\x03pts\x18\x14 \x01(\x03\x12\x13\n\x0b\x63ooperation\x18\x15 \x01(\t\x12\x11\n\tattribute\x18\x16 \x01(\x05\x12\x10\n\x08\x66ollower\x18\x17 \x01(\x03\x12=\n\x0fofficial_verify\x18\x18 \x01(\x0b\x32$.bilibili.app.show.v1.OfficialVerify\x12,\n\x08\x63hildren\x18\x19 \x03(\x0b\x32\x1a.bilibili.app.show.v1.Item\x12\x30\n\x08relation\x18\x1a \x01(\x0b\x32\x1e.bilibili.app.show.v1.Relation\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"9\n\x10RankAllResultReq\x12\r\n\x05order\x18\x01 \x01(\t\x12\n\n\x02pn\x18\x02 \x01(\x05\x12\n\n\x02ps\x18\x03 \x01(\x05\":\n\rRankListReply\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.bilibili.app.show.v1.Item\":\n\x13RankRegionResultReq\x12\x0b\n\x03rid\x18\x01 \x01(\x05\x12\n\n\x02pn\x18\x02 \x01(\x05\x12\n\n\x02ps\x18\x03 \x01(\x05\"B\n\x08Relation\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x32\xbc\x01\n\x04Rank\x12V\n\x07RankAll\x12&.bilibili.app.show.v1.RankAllResultReq\x1a#.bilibili.app.show.v1.RankListReply\x12\\\n\nRankRegion\x12).bilibili.app.show.v1.RankRegionResultReq\x1a#.bilibili.app.show.v1.RankListReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.show.rank.v1.rank_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ITEM._serialized_start=63
  _ITEM._serialized_end=590
  _OFFICIALVERIFY._serialized_start=592
  _OFFICIALVERIFY._serialized_end=636
  _RANKALLRESULTREQ._serialized_start=638
  _RANKALLRESULTREQ._serialized_end=695
  _RANKLISTREPLY._serialized_start=697
  _RANKLISTREPLY._serialized_end=755
  _RANKREGIONRESULTREQ._serialized_start=757
  _RANKREGIONRESULTREQ._serialized_end=815
  _RELATION._serialized_start=817
  _RELATION._serialized_end=883
  _RANK._serialized_start=886
  _RANK._serialized_end=1074
# @@protoc_insertion_point(module_scope)



from ..utils import get

BASE_URL = "https://api.bilibili.com"


async def get_meta(media_id: int, auth=None, reqtype="app", **kwargs):
    """根据番剧 ID 获取番剧元数据信息"""
    url = f"{BASE_URL}/pgc/review/user"
    params = {"media_id": media_id}
    raw_json = await get(
        url, raw=True, params=params, auth=auth, reqtype=reqtype, **kwargs
    )
    return raw_json["result"]



# TODO 对这部分重构
from re import compile
from typing import Union


class VideoID:
    # 哔哩哔哩视频ID类
    # TODO 对avid>=29460791296进行处理（虽然这种情况还很遥远）
    def __init__(self, id: Union[int, str]):
        if isinstance(id, int):
            self.aid = id
            self.bvid = av2bv(id)
        else:
            # 构造正则表达式对象
            av_pattern = compile(r"av[0-9]*")
            bv_pattern = compile(r"BV1[A-Za-z0-9]{9}")
            if av_pattern.match(id):
                self.aid = int(id[2:])
                self.bvid = av2bv(self.aid)
            elif bv_pattern.match(id):
                # 进一步判断是否为合法的视频id
                if id[5] != "4":
                    raise ValueError("Invalid video id.")
                elif id[7] != "1":
                    raise ValueError("Invalid video id.")
                elif id[9] != "7":
                    raise ValueError("Invalid video id.")
                self.bvid = id
                self.aid = bv2av(id)
            else:
                raise ValueError("Invalid video id.")


table = "fZodR9XQDSUm21yCkr6zBqiveYah8bt4xsWpHnJE7jL5VG3guMTKNPAwcF"
tr = {}
for i in range(58):
    tr[table[i]] = i
s = [11, 10, 3, 8, 4, 6]
xor = 177451812
add = 8728348608


def av2bv(aid: int) -> str:
    aid = (aid ^ xor) + add
    r = list("BV1  4 1 7  ")
    for i in range(6):
        r[s[i]] = table[aid // 58**i % 58]
    return "".join(r)


def bv2av(bid: str) -> int:
    r = 0
    for i in range(6):
        r += tr[bid[s[i]]] * 58**i
    return (r - add) ^ xor



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NativePageEvent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGEID_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    PageID: builtins.int
    """Native页ID"""
    @property
    def Items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventItem]:
        """"""
    def __init__(
        self,
        *,
        PageID: builtins.int = ...,
        Items: collections.abc.Iterable[global___EventItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["Items", b"Items", "PageID", b"PageID"]) -> None: ...

global___NativePageEvent = NativePageEvent

@typing_extensions.final
class EventItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    DISPLAYNUM_FIELD_NUMBER: builtins.int
    WEBKEY_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    ItemID: builtins.int
    """组件标识"""
    Type: builtins.str
    """组件类型"""
    Num: builtins.int
    """进度条数值"""
    DisplayNum: builtins.str
    """进度条展示数值"""
    WebKey: builtins.str
    """h5的组件标识"""
    dimension: builtins.int
    """活动统计维度
    0:用户维度 1:规则维度
    """
    def __init__(
        self,
        *,
        ItemID: builtins.int = ...,
        Type: builtins.str = ...,
        Num: builtins.int = ...,
        DisplayNum: builtins.str = ...,
        WebKey: builtins.str = ...,
        dimension: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["DisplayNum", b"DisplayNum", "ItemID", b"ItemID", "Num", b"Num", "Type", b"Type", "WebKey", b"WebKey", "dimension", b"dimension"]) -> None: ...

global___EventItem = EventItem



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/laser.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/broadcast/v1/laser.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x1bgoogle/protobuf/empty.proto\"2\n\x12LaserLogUploadResp\x12\x0e\n\x06taskid\x18\x01 \x01(\x03\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\t2c\n\x05Laser\x12Z\n\x13WatchLogUploadEvent\x12\x16.google.protobuf.Empty\x1a).bilibili.broadcast.v1.LaserLogUploadResp0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.v1.laser_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LASERLOGUPLOADRESP._serialized_start=89
  _LASERLOGUPLOADRESP._serialized_end=139
  _LASER._serialized_start=141
  _LASER._serialized_end=240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/main/community/reply/v1/reply.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/main/community/reply/v1/reply.proto\x12 bilibili.main.community.reply.v1\x1a\x19google/protobuf/any.proto\"U\n\x08\x41\x63tivity\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x16\n\x0e\x61\x63tivity_state\x18\x02 \x01(\x03\x12\x1c\n\x14\x61\x63tivity_placeholder\x18\x03 \x01(\t\"G\n\x11\x41rticleSearchItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bup_nickname\x18\x02 \x01(\t\x12\x0e\n\x06\x63overs\x18\x03 \x03(\t\"j\n\x07\x41tGroup\x12\x12\n\ngroup_type\x18\x01 \x01(\x05\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x37\n\x05items\x18\x03 \x03(\x0b\x32(.bilibili.main.community.reply.v1.AtItem\"]\n\x06\x41tItem\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x04 \x01(\x05\x12\x1c\n\x14official_verify_type\x18\x05 \x01(\x05\"J\n\rAtSearchReply\x12\x39\n\x06groups\x18\x01 \x03(\x0b\x32).bilibili.main.community.reply.v1.AtGroup\"+\n\x0b\x41tSearchReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"2\n\x02\x43M\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"\xc0\x07\n\x07\x43ontent\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x45\n\x06menber\x18\x02 \x03(\x0b\x32\x35.bilibili.main.community.reply.v1.Content.MenberEntry\x12\x43\n\x05\x65mote\x18\x03 \x03(\x0b\x32\x34.bilibili.main.community.reply.v1.Content.EmoteEntry\x12\x43\n\x05topic\x18\x04 \x03(\x0b\x32\x34.bilibili.main.community.reply.v1.Content.TopicEntry\x12?\n\x03url\x18\x05 \x03(\x0b\x32\x32.bilibili.main.community.reply.v1.Content.UrlEntry\x12\x34\n\x04vote\x18\x06 \x01(\x0b\x32&.bilibili.main.community.reply.v1.Vote\x12R\n\x0e\x61t_name_to_mid\x18\x07 \x03(\x0b\x32:.bilibili.main.community.reply.v1.Content.AtNameToMidEntry\x12=\n\trich_text\x18\x08 \x01(\x0b\x32*.bilibili.main.community.reply.v1.RichText\x12;\n\x08pictures\x18\t \x03(\x0b\x32).bilibili.main.community.reply.v1.Picture\x1aW\n\x0bMenberEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member:\x02\x38\x01\x1aU\n\nEmoteEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.bilibili.main.community.reply.v1.Emote:\x02\x38\x01\x1aU\n\nTopicEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.bilibili.main.community.reply.v1.Topic:\x02\x38\x01\x1aQ\n\x08UrlEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.bilibili.main.community.reply.v1.Url:\x02\x38\x01\x1a\x32\n\x10\x41tNameToMidEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"S\n\x07Picture\x12\x0f\n\x07img_src\x18\x01 \x01(\t\x12\x11\n\timg_width\x18\x02 \x01(\x01\x12\x12\n\nimg_height\x18\x03 \x01(\x01\x12\x10\n\x08img_size\x18\x04 \x01(\x01\"\x92\x01\n\x0b\x43ursorReply\x12\x0c\n\x04next\x18\x01 \x01(\x03\x12\x0c\n\x04prev\x18\x02 \x01(\x03\x12\x0f\n\x07isBegin\x18\x03 \x01(\x08\x12\r\n\x05isEnd\x18\x04 \x01(\x08\x12\x34\n\x04mode\x18\x05 \x01(\x0e\x32&.bilibili.main.community.reply.v1.Mode\x12\x11\n\tmode_text\x18\x06 \x01(\t\"]\n\tCursorReq\x12\x0c\n\x04next\x18\x01 \x01(\x03\x12\x0c\n\x04prev\x18\x02 \x01(\x03\x12\x34\n\x04mode\x18\x04 \x01(\x0e\x32&.bilibili.main.community.reply.v1.Mode\"\xcf\x02\n\x0f\x44\x65tailListReply\x12=\n\x06\x63ursor\x18\x01 \x01(\x0b\x32-.bilibili.main.community.reply.v1.CursorReply\x12I\n\x0fsubject_control\x18\x02 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.SubjectControl\x12\x39\n\x04root\x18\x03 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12<\n\x08\x61\x63tivity\x18\x04 \x01(\x0b\x32*.bilibili.main.community.reply.v1.Activity\x12\x39\n\x05likes\x18\x05 \x01(\x0b\x32*.bilibili.main.community.reply.v1.LikeInfo\"\xc5\x01\n\rDetailListReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\x0c\n\x04root\x18\x03 \x01(\x03\x12\x0c\n\x04rpid\x18\x04 \x01(\x03\x12;\n\x06\x63ursor\x18\x05 \x01(\x0b\x32+.bilibili.main.community.reply.v1.CursorReq\x12@\n\x05scene\x18\x06 \x01(\x0e\x32\x31.bilibili.main.community.reply.v1.DetailListScene\"\x97\x02\n\x0f\x44ialogListReply\x12=\n\x06\x63ursor\x18\x01 \x01(\x0b\x32-.bilibili.main.community.reply.v1.CursorReply\x12I\n\x0fsubject_control\x18\x02 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.SubjectControl\x12<\n\x07replies\x18\x03 \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12<\n\x08\x61\x63tivity\x18\x04 \x01(\x0b\x32*.bilibili.main.community.reply.v1.Activity\"\x83\x01\n\rDialogListReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\x0c\n\x04root\x18\x03 \x01(\x03\x12\x0c\n\x04rpid\x18\x04 \x01(\x03\x12;\n\x06\x63ursor\x18\x05 \x01(\x0b\x32+.bilibili.main.community.reply.v1.CursorReq\"\x1d\n\x07\x45\x66\x66\x65\x63ts\x12\x12\n\npreloading\x18\x01 \x01(\t\"\x87\x01\n\x05\x45mote\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x12\n\njump_title\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\x12\x12\n\npackage_id\x18\x06 \x01(\x03\x12\x0f\n\x07gif_url\x18\x07 \x01(\t\x12\x0c\n\x04text\x18\x08 \x01(\t\"f\n\x0fGoodsSearchItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\t\x12\x0e\n\x06income\x18\x04 \x01(\t\x12\x0b\n\x03img\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\"\x9b\x01\n\x08LikeInfo\x12>\n\x05items\x18\x01 \x03(\x0b\x32/.bilibili.main.community.reply.v1.LikeInfo.Item\x12\r\n\x05title\x18\x02 \x01(\t\x1a@\n\x04Item\x12\x38\n\x06member\x18\x01 \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member\"\xc7\x02\n\x07Lottery\x12\x12\n\nlottery_id\x18\x01 \x01(\x03\x12\x16\n\x0elottery_status\x18\x02 \x01(\x03\x12\x13\n\x0blottery_mid\x18\x03 \x01(\x03\x12\x14\n\x0clottery_time\x18\x04 \x01(\x03\x12\x0b\n\x03oid\x18\x05 \x01(\x03\x12\x0c\n\x04type\x18\x06 \x01(\x03\x12\r\n\x05\x63time\x18\x07 \x01(\x03\x12:\n\x07\x63ontent\x18\x08 \x01(\x0b\x32).bilibili.main.community.reply.v1.Content\x12\x38\n\x06member\x18\t \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member\x12\x45\n\rreply_control\x18\n \x01(\x0b\x32..bilibili.main.community.reply.v1.ReplyControl\"\xb9\x08\n\rMainListReply\x12=\n\x06\x63ursor\x18\x01 \x01(\x0b\x32-.bilibili.main.community.reply.v1.CursorReply\x12<\n\x07replies\x18\x02 \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12I\n\x0fsubject_control\x18\x03 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.SubjectControl\x12;\n\x06up_top\x18\x04 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12>\n\tadmin_top\x18\x05 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12=\n\x08vote_top\x18\x06 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12\x38\n\x06notice\x18\x07 \x01(\x0b\x32(.bilibili.main.community.reply.v1.Notice\x12:\n\x07lottery\x18\x08 \x01(\x0b\x32).bilibili.main.community.reply.v1.Lottery\x12<\n\x08\x61\x63tivity\x18\t \x01(\x0b\x32*.bilibili.main.community.reply.v1.Activity\x12\x43\n\x0cup_selection\x18\n \x01(\x0b\x32-.bilibili.main.community.reply.v1.UpSelection\x12\x30\n\x02\x63m\x18\x0b \x01(\x0b\x32$.bilibili.main.community.reply.v1.CM\x12:\n\x07\x65\x66\x66\x65\x63ts\x18\x0c \x01(\x0b\x32).bilibili.main.community.reply.v1.Effects\x12>\n\toperation\x18\r \x01(\x0b\x32+.bilibili.main.community.reply.v1.Operation\x12@\n\x0btop_replies\x18\x0e \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12\x36\n\x03qoe\x18\x0f \x01(\x0b\x32).bilibili.main.community.reply.v1.QoeInfo\x12Q\n\tcallbacks\x18\x10 \x03(\x0b\x32>.bilibili.main.community.reply.v1.MainListReply.CallbacksEntry\x1a\x30\n\x0e\x43\x61llbacksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\xc0\x01\n\x0bMainListReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12;\n\x06\x63ursor\x18\x03 \x01(\x0b\x32+.bilibili.main.community.reply.v1.CursorReq\x12\r\n\x05\x65xtra\x18\x04 \x01(\t\x12\x10\n\x08\x61\x64_extra\x18\x05 \x01(\t\x12\x0c\n\x04rpid\x18\x06 \x01(\x03\x12\x11\n\tseek_rpid\x18\x07 \x01(\x03\x12\x17\n\x0f\x66ilter_tag_name\x18\x08 \x01(\t\"\xba\n\n\x06Member\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\x03\x12\x1c\n\x14official_verify_type\x18\x06 \x01(\x03\x12\x10\n\x08vip_type\x18\x07 \x01(\x03\x12\x12\n\nvip_status\x18\x08 \x01(\x03\x12\x16\n\x0evip_theme_type\x18\t \x01(\x03\x12\x16\n\x0evip_label_path\x18\n \x01(\t\x12\x1a\n\x12garb_pendant_image\x18\x0b \x01(\t\x12\x17\n\x0fgarb_card_image\x18\x0c \x01(\t\x12\"\n\x1agarb_card_image_with_focus\x18\r \x01(\t\x12\x1a\n\x12garb_card_jump_url\x18\x0e \x01(\t\x12\x18\n\x10garb_card_number\x18\x0f \x01(\t\x12\x1b\n\x13garb_card_fan_color\x18\x10 \x01(\t\x12\x18\n\x10garb_card_is_fan\x18\x11 \x01(\x08\x12\x17\n\x0f\x66\x61ns_medal_name\x18\x12 \x01(\t\x12\x18\n\x10\x66\x61ns_medal_level\x18\x13 \x01(\x03\x12\x18\n\x10\x66\x61ns_medal_color\x18\x14 \x01(\x03\x12\x1a\n\x12vip_nickname_color\x18\x15 \x01(\t\x12\x1c\n\x14vip_avatar_subscript\x18\x16 \x01(\x05\x12\x16\n\x0evip_label_text\x18\x17 \x01(\t\x12\x17\n\x0fvip_label_theme\x18\x18 \x01(\t\x12\x1c\n\x14\x66\x61ns_medal_color_end\x18\x19 \x01(\x03\x12\x1f\n\x17\x66\x61ns_medal_color_border\x18\x1a \x01(\x03\x12\x1d\n\x15\x66\x61ns_medal_color_name\x18\x1b \x01(\x03\x12\x1e\n\x16\x66\x61ns_medal_color_level\x18\x1c \x01(\x03\x12\x18\n\x10\x66\x61ns_guard_level\x18\x1d \x01(\x03\x12\x10\n\x08\x66\x61\x63\x65_nft\x18\x1e \x01(\x05\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\x1f \x01(\x05\x12\x18\n\x10is_senior_member\x18  \x01(\x05\x12P\n\x0fnft_interaction\x18! \x01(\x0b\x32\x37.bilibili.main.community.reply.v1.Member.NftInteraction\x12\x17\n\x0f\x66\x61ns_guard_icon\x18\" \x01(\t\x12\x17\n\x0f\x66\x61ns_honor_icon\x18# \x01(\t\x1a\xa3\x01\n\x06Region\x12\x41\n\x04type\x18\x01 \x01(\x0e\x32\x33.bilibili.main.community.reply.v1.Member.RegionType\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12H\n\x0bshow_status\x18\x03 \x01(\x0e\x32\x33.bilibili.main.community.reply.v1.Member.ShowStatus\x1a\x86\x01\n\x0eNftInteraction\x12\r\n\x05itype\x18\x01 \x01(\t\x12\x14\n\x0cmetadata_url\x18\x02 \x01(\t\x12\x0e\n\x06nft_id\x18\x03 \x01(\t\x12?\n\x06region\x18\x04 \x01(\x0b\x32/.bilibili.main.community.reply.v1.Member.Region\"0\n\nRegionType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08MAINLAND\x10\x01\x12\x07\n\x03GAT\x10\x02\":\n\nShowStatus\x12\x0f\n\x0bSHOWDEFAULT\x10\x00\x12\x12\n\x0eZOOMINMAINLAND\x10\x01\x12\x07\n\x03RAW\x10\x02\"\x93\x0e\n\x08MemberV2\x12?\n\x05\x62\x61sic\x18\x01 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.MemberV2.Basic\x12\x45\n\x08official\x18\x02 \x01(\x0b\x32\x33.bilibili.main.community.reply.v1.MemberV2.Official\x12;\n\x03vip\x18\x03 \x01(\x0b\x32..bilibili.main.community.reply.v1.MemberV2.Vip\x12=\n\x04garb\x18\x04 \x01(\x0b\x32/.bilibili.main.community.reply.v1.MemberV2.Garb\x12?\n\x05medal\x18\x05 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.MemberV2.Medal\x12;\n\x03nft\x18\x06 \x01(\x0b\x32..bilibili.main.community.reply.v1.MemberV2.Nft\x12\x41\n\x06senior\x18\x07 \x01(\x0b\x32\x31.bilibili.main.community.reply.v1.MemberV2.Senior\x12I\n\ncontractor\x18\x08 \x01(\x0b\x32\x35.bilibili.main.community.reply.v1.MemberV2.Contractor\x1aL\n\x05\x42\x61sic\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\x03\x1a\x1f\n\x08Official\x12\x13\n\x0bverify_type\x18\x01 \x01(\x03\x1a\xaa\x01\n\x03Vip\x12\x0c\n\x04type\x18\x01 \x01(\x03\x12\x0e\n\x06status\x18\x02 \x01(\x03\x12\x12\n\ntheme_type\x18\x03 \x01(\x03\x12\x12\n\nlabel_path\x18\x04 \x01(\t\x12\x16\n\x0enickname_color\x18\x05 \x01(\t\x12\x18\n\x10\x61vatar_subscript\x18\x06 \x01(\x05\x12\x12\n\nlabel_text\x18\x07 \x01(\t\x12\x17\n\x0fvip_label_theme\x18\x08 \x01(\t\x1a\xa9\x01\n\x04Garb\x12\x15\n\rpendant_image\x18\x01 \x01(\t\x12\x12\n\ncard_image\x18\x02 \x01(\t\x12\x1d\n\x15\x63\x61rd_image_with_focus\x18\x03 \x01(\t\x12\x15\n\rcard_jump_url\x18\x04 \x01(\t\x12\x13\n\x0b\x63\x61rd_number\x18\x05 \x01(\t\x12\x16\n\x0e\x63\x61rd_fan_color\x18\x06 \x01(\t\x12\x13\n\x0b\x63\x61rd_is_fan\x18\x07 \x01(\x08\x1a\xcc\x01\n\x05Medal\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x03\x12\x13\n\x0b\x63olor_start\x18\x03 \x01(\x03\x12\x11\n\tcolor_end\x18\x04 \x01(\x03\x12\x14\n\x0c\x63olor_border\x18\x05 \x01(\x03\x12\x12\n\ncolor_name\x18\x06 \x01(\x03\x12\x13\n\x0b\x63olor_level\x18\x07 \x01(\x03\x12\x13\n\x0bguard_level\x18\x08 \x01(\x03\x12\x12\n\nfirst_icon\x18\t \x01(\t\x12\x16\n\x0elevel_bg_color\x18\x0b \x01(\x03\x1a\xa7\x01\n\x06Region\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.bilibili.main.community.reply.v1.MemberV2.RegionType\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12J\n\x0bshow_status\x18\x03 \x01(\x0e\x32\x35.bilibili.main.community.reply.v1.MemberV2.ShowStatus\x1a\x85\x01\n\x0bInteraction\x12\r\n\x05itype\x18\x01 \x01(\t\x12\x14\n\x0cmetadata_url\x18\x02 \x01(\t\x12\x0e\n\x06nft_id\x18\x03 \x01(\t\x12\x41\n\x06region\x18\x04 \x01(\x0b\x32\x31.bilibili.main.community.reply.v1.MemberV2.Region\x1a`\n\x03Nft\x12\x0c\n\x04\x66\x61\x63\x65\x18\x01 \x01(\x05\x12K\n\x0binteraction\x18\x02 \x01(\x0b\x32\x36.bilibili.main.community.reply.v1.MemberV2.Interaction\x1a\"\n\x06Senior\x12\x18\n\x10is_senior_member\x18\x01 \x01(\x05\x1a:\n\nContractor\x12\x15\n\ris_contractor\x18\x01 \x01(\x08\x12\x15\n\rcontract_desc\x18\x02 \x01(\t\"0\n\nRegionType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08MAINLAND\x10\x01\x12\x07\n\x03GAT\x10\x02\":\n\nShowStatus\x12\x0f\n\x0bSHOWDEFAULT\x10\x00\x12\x12\n\x0eZOOMINMAINLAND\x10\x01\x12\x07\n\x03RAW\x10\x02\"3\n\x06Notice\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xdc\x01\n\tOperation\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12?\n\x05title\x18\x03 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.OperationTitle\x12\x42\n\x08subtitle\x18\x04 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.OperationTitle\x12\x0c\n\x04link\x18\x05 \x01(\t\x12\x14\n\x0creport_extra\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\"7\n\x0eOperationTitle\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x14\n\x0cis_highlight\x18\x02 \x01(\x08\"D\n\x12PGCVideoSearchItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\x95\x03\n\x10PreviewListReply\x12=\n\x06\x63ursor\x18\x01 \x01(\x0b\x32-.bilibili.main.community.reply.v1.CursorReply\x12<\n\x07replies\x18\x02 \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12I\n\x0fsubject_control\x18\x03 \x01(\x0b\x32\x30.bilibili.main.community.reply.v1.SubjectControl\x12:\n\x05upTop\x18\x04 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12>\n\tadmin_top\x18\x05 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12=\n\x08vote_top\x18\x06 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\"h\n\x0ePreviewListReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12;\n\x06\x63ursor\x18\x03 \x01(\x0b\x32+.bilibili.main.community.reply.v1.CursorReq\"\xb4\x01\n\x07QoeInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\r\n\x05style\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\x12\x16\n\x0e\x66\x65\x65\x64\x62\x61\x63k_title\x18\x05 \x01(\t\x12\x43\n\x0bscore_items\x18\x06 \x03(\x0b\x32..bilibili.main.community.reply.v1.QoeScoreItem\x12\x14\n\x0c\x64isplay_rank\x18\x07 \x01(\x03\"9\n\x0cQoeScoreItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x02\"\xaf\x02\n\x0eReplyCardLabel\x12\x14\n\x0ctext_content\x18\x01 \x01(\t\x12\x16\n\x0etext_color_day\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x17\n\x0flabel_color_day\x18\x04 \x01(\t\x12\x19\n\x11label_color_night\x18\x05 \x01(\t\x12\r\n\x05image\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\x05\x12\x12\n\nbackground\x18\x08 \x01(\t\x12\x18\n\x10\x62\x61\x63kground_width\x18\t \x01(\x01\x12\x19\n\x11\x62\x61\x63kground_height\x18\n \x01(\x01\x12\x10\n\x08jump_url\x18\x0b \x01(\t\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x0c \x01(\x03\x12\x19\n\x11\x65\x66\x66\x65\x63t_start_time\x18\r \x01(\x03\"\xc7\x04\n\x0cReplyControl\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x03\x12\x0f\n\x07up_like\x18\x02 \x01(\x08\x12\x10\n\x08up_reply\x18\x03 \x01(\x08\x12\x17\n\x0fshow_follow_btn\x18\x04 \x01(\x08\x12\x11\n\tis_assist\x18\x05 \x01(\x08\x12\x12\n\nlabel_text\x18\x06 \x01(\t\x12\x11\n\tfollowing\x18\x07 \x01(\x08\x12\x10\n\x08\x66ollowed\x18\x08 \x01(\x08\x12\x0f\n\x07\x62locked\x18\t \x01(\x08\x12\x18\n\x10has_folded_reply\x18\n \x01(\x08\x12\x17\n\x0fis_folded_reply\x18\x0b \x01(\x08\x12\x11\n\tis_up_top\x18\x0c \x01(\x08\x12\x14\n\x0cis_admin_top\x18\r \x01(\x08\x12\x13\n\x0bis_vote_top\x18\x0e \x01(\x08\x12\x10\n\x08max_line\x18\x0f \x01(\x03\x12\x11\n\tinvisible\x18\x10 \x01(\x08\x12\x15\n\ris_contractor\x18\x11 \x01(\x08\x12\x0f\n\x07is_note\x18\x12 \x01(\x08\x12\x45\n\x0b\x63\x61rd_labels\x18\x13 \x03(\x0b\x32\x30.bilibili.main.community.reply.v1.ReplyCardLabel\x12\x1c\n\x14sub_reply_entry_text\x18\x14 \x01(\t\x12\x1c\n\x14sub_reply_title_text\x18\x15 \x01(\t\x12\x15\n\rcontract_desc\x18\x16 \x01(\t\x12\x11\n\ttime_desc\x18\x17 \x01(\t\x12\x11\n\tbiz_scene\x18\x18 \x01(\t\x12\x10\n\x08location\x18\x19 \x01(\t\"U\n\nReplyExtra\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x13\n\x0bseason_type\x18\x02 \x01(\x03\x12\r\n\x05\x65p_id\x18\x03 \x01(\x03\x12\x10\n\x08is_story\x18\x04 \x01(\x08\"\xd3\x03\n\tReplyInfo\x12<\n\x07replies\x18\x01 \x03(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x03\x12\x0b\n\x03mid\x18\x05 \x01(\x03\x12\x0c\n\x04root\x18\x06 \x01(\x03\x12\x0e\n\x06parent\x18\x07 \x01(\x03\x12\x0e\n\x06\x64ialog\x18\x08 \x01(\x03\x12\x0c\n\x04like\x18\t \x01(\x03\x12\r\n\x05\x63time\x18\n \x01(\x03\x12\r\n\x05\x63ount\x18\x0b \x01(\x03\x12:\n\x07\x63ontent\x18\x0c \x01(\x0b\x32).bilibili.main.community.reply.v1.Content\x12\x38\n\x06member\x18\r \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member\x12\x45\n\rreply_control\x18\x0e \x01(\x0b\x32..bilibili.main.community.reply.v1.ReplyControl\x12=\n\tmember_v2\x18\x0f \x01(\x0b\x32*.bilibili.main.community.reply.v1.MemberV2\"L\n\x0eReplyInfoReply\x12:\n\x05reply\x18\x01 \x01(\x0b\x32+.bilibili.main.community.reply.v1.ReplyInfo\"+\n\x0cReplyInfoReq\x12\x0c\n\x04rpid\x18\x01 \x01(\x03\x12\r\n\x05scene\x18\x02 \x01(\x05\"R\n\x08RichText\x12>\n\x04note\x18\x01 \x01(\x0b\x32..bilibili.main.community.reply.v1.RichTextNoteH\x00\x42\x06\n\x04item\"[\n\x0cRichTextNote\x12\x0f\n\x07summary\x18\x01 \x01(\t\x12\x0e\n\x06images\x18\x02 \x03(\t\x12\x11\n\tclick_url\x18\x03 \x01(\t\x12\x17\n\x0flast_mtime_text\x18\x04 \x01(\t\"\xf1\x01\n\nSearchItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x42\n\x05goods\x18\x02 \x01(\x0b\x32\x31.bilibili.main.community.reply.v1.GoodsSearchItemH\x00\x12\x42\n\x05video\x18\x03 \x01(\x0b\x32\x31.bilibili.main.community.reply.v1.VideoSearchItemH\x00\x12\x46\n\x07\x61rticle\x18\x04 \x01(\x0b\x32\x33.bilibili.main.community.reply.v1.ArticleSearchItemH\x00\x42\x06\n\x04item\"7\n\x15SearchItemCursorReply\x12\x10\n\x08has_next\x18\x01 \x01(\x08\x12\x0c\n\x04next\x18\x02 \x01(\x03\"h\n\x13SearchItemCursorReq\x12\x0c\n\x04next\x18\x01 \x01(\x03\x12\x43\n\titem_type\x18\x02 \x01(\x0e\x32\x30.bilibili.main.community.reply.v1.SearchItemType\"\x93\x01\n\x16SearchItemPreHookReply\x12\x18\n\x10placeholder_text\x18\x01 \x01(\t\x12\x17\n\x0f\x62\x61\x63kground_text\x18\x02 \x01(\t\x12\x46\n\x0cordered_type\x18\x03 \x03(\x0e\x32\x30.bilibili.main.community.reply.v1.SearchItemType\"1\n\x14SearchItemPreHookReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\"\xe2\x01\n\x0fSearchItemReply\x12G\n\x06\x63ursor\x18\x01 \x01(\x0b\x32\x37.bilibili.main.community.reply.v1.SearchItemCursorReply\x12;\n\x05items\x18\x02 \x03(\x0b\x32,.bilibili.main.community.reply.v1.SearchItem\x12I\n\x05\x65xtra\x18\x03 \x01(\x0b\x32:.bilibili.main.community.reply.v1.SearchItemReplyExtraInfo\",\n\x18SearchItemReplyExtraInfo\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\"\x82\x01\n\rSearchItemReq\x12\x45\n\x06\x63ursor\x18\x01 \x01(\x0b\x32\x35.bilibili.main.community.reply.v1.SearchItemCursorReq\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x03\x12\x0f\n\x07keyword\x18\x04 \x01(\t\"?\n\x13ShareRepliesInfoReq\x12\r\n\x05rpids\x18\x01 \x03(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x03\"\xf6\x02\n\x14ShareRepliesInfoResp\x12?\n\x05infos\x18\x01 \x03(\x0b\x32\x30.bilibili.main.community.reply.v1.ShareReplyInfo\x12\x12\n\nfrom_title\x18\x02 \x01(\t\x12\x0f\n\x07\x66rom_up\x18\x03 \x01(\t\x12\x10\n\x08\x66rom_pic\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x12\n\nslogan_pic\x18\x06 \x01(\t\x12\x13\n\x0bslogan_text\x18\x07 \x01(\t\x12@\n\x05topic\x18\x08 \x01(\x0b\x32\x31.bilibili.main.community.reply.v1.ShareReplyTopic\x12P\n\x05\x65xtra\x18\t \x01(\x0b\x32\x41.bilibili.main.community.reply.v1.ShareRepliesInfoResp.ShareExtra\x1a\x1c\n\nShareExtra\x12\x0e\n\x06is_pgc\x18\x01 \x01(\x08\"\xd5\x01\n\x0eShareReplyInfo\x12\x38\n\x06member\x18\x01 \x01(\x0b\x32(.bilibili.main.community.reply.v1.Member\x12:\n\x07\x63ontent\x18\x02 \x01(\x0b\x32).bilibili.main.community.reply.v1.Content\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\x18\n\x10\x61\x63hievement_text\x18\x05 \x01(\t\x12\x11\n\tlabel_url\x18\x06 \x01(\t\"^\n\x0fShareReplyTopic\x12\x36\n\x05topic\x18\x01 \x01(\x0b\x32\'.bilibili.main.community.reply.v1.Topic\x12\x13\n\x0borigin_text\x18\x02 \x01(\t\"\xb2\x05\n\x0eSubjectControl\x12\x0e\n\x06up_mid\x18\x01 \x01(\x03\x12\x11\n\tis_assist\x18\x02 \x01(\x08\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x17\n\x0fhas_vote_access\x18\x04 \x01(\x08\x12\x1a\n\x12has_lottery_access\x18\x05 \x01(\x08\x12\x18\n\x10has_folded_reply\x18\x06 \x01(\x08\x12\x0f\n\x07\x62g_text\x18\x07 \x01(\t\x12\x12\n\nup_blocked\x18\x08 \x01(\x08\x12\x1b\n\x13has_activity_access\x18\t \x01(\x08\x12\x12\n\nshow_title\x18\n \x01(\x08\x12\x16\n\x0eshow_up_action\x18\x0b \x01(\x08\x12\x15\n\rswitcher_type\x18\x0c \x01(\x03\x12\x15\n\rinput_disable\x18\r \x01(\x08\x12\x11\n\troot_text\x18\x0e \x01(\t\x12\x12\n\nchild_text\x18\x0f \x01(\t\x12\r\n\x05\x63ount\x18\x10 \x01(\x03\x12\r\n\x05title\x18\x11 \x01(\t\x12\x13\n\x0bgiveup_text\x18\x12 \x01(\t\x12\x17\n\x0fhas_note_access\x18\x13 \x01(\x08\x12\x1a\n\x12\x64isable_jump_emote\x18\x14 \x01(\x08\x12#\n\x1b\x65mpty_background_text_plain\x18\x15 \x01(\t\x12\'\n\x1f\x65mpty_background_text_highlight\x18\x16 \x01(\t\x12\x1c\n\x14\x65mpty_background_uri\x18\x17 \x01(\t\x12W\n\x13support_filter_tags\x18\x18 \x03(\x0b\x32:.bilibili.main.community.reply.v1.SubjectControl.FilterTag\x1a+\n\tFilterTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\"-\n\x10SuggestEmotesReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\"L\n\x11SuggestEmotesResp\x12\x37\n\x06\x65motes\x18\x01 \x03(\x0b\x32\'.bilibili.main.community.reply.v1.Emote\"!\n\x05Topic\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"Y\n\x12UGCVideoSearchItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bup_nickname\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\r\n\x05\x63over\x18\x04 \x01(\t\":\n\x0bUpSelection\x12\x15\n\rpending_count\x18\x01 \x01(\x03\x12\x14\n\x0cignore_count\x18\x02 \x01(\x03\"\xd9\x03\n\x03Url\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\x03\x12\x13\n\x0bprefix_icon\x18\x03 \x01(\t\x12\x16\n\x0e\x61pp_url_schema\x18\x04 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x05 \x01(\t\x12\x18\n\x10\x61pp_package_name\x18\x06 \x01(\t\x12\x14\n\x0c\x63lick_report\x18\x07 \x01(\t\x12\x16\n\x0eis_half_screen\x18\x08 \x01(\x08\x12\x17\n\x0f\x65xposure_report\x18\t \x01(\t\x12:\n\x05\x65xtra\x18\n \x01(\x0b\x32+.bilibili.main.community.reply.v1.Url.Extra\x12\x11\n\tunderline\x18\x0b \x01(\x08\x12\x12\n\nmatch_once\x18\x0c \x01(\x08\x12\x0e\n\x06pc_url\x18\r \x01(\t\x12\x15\n\ricon_position\x18\x0e \x01(\x05\x1a\x89\x01\n\x05\x45xtra\x12\x15\n\rgoods_item_id\x18\x01 \x01(\x03\x12\x1e\n\x16goods_prefetched_cache\x18\x02 \x01(\t\x12\x17\n\x0fgoods_show_type\x18\x03 \x01(\x05\x12\x16\n\x0eis_word_search\x18\x04 \x01(\x08\x12\x18\n\x10goods_cm_control\x18\x05 \x01(\x03\"\x13\n\x11UserCallbackReply\"\xc3\x01\n\x0fUserCallbackReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x42\n\x05scene\x18\x02 \x01(\x0e\x32\x33.bilibili.main.community.reply.v1.UserCallbackScene\x12\x44\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x34.bilibili.main.community.reply.v1.UserCallbackAction\x12\x0b\n\x03oid\x18\x04 \x01(\x03\x12\x0c\n\x04type\x18\x05 \x01(\x03\"\xf1\x01\n\x0fVideoSearchItem\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x38.bilibili.main.community.reply.v1.SearchItemVideoSubType\x12\x43\n\x03ugc\x18\x02 \x01(\x0b\x32\x34.bilibili.main.community.reply.v1.UGCVideoSearchItemH\x00\x12\x43\n\x03pgc\x18\x03 \x01(\x0b\x32\x34.bilibili.main.community.reply.v1.PGCVideoSearchItemH\x00\x42\x0c\n\nvideo_item\"0\n\x04Vote\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x03*6\n\x0f\x44\x65tailListScene\x12\t\n\x05REPLY\x10\x00\x12\x0c\n\x08MSG_FEED\x10\x01\x12\n\n\x06NOTIFY\x10\x02*K\n\x04Mode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0f\n\x0bUNSPECIFIED\x10\x01\x12\x12\n\x0eMAIN_LIST_TIME\x10\x02\x12\x11\n\rMAIN_LIST_HOT\x10\x03*J\n\x0eSearchItemType\x12\x15\n\x11\x44\x45\x46\x41ULT_ITEM_TYPE\x10\x00\x12\t\n\x05GOODS\x10\x01\x12\t\n\x05VIDEO\x10\x02\x12\x0b\n\x07\x41RTICLE\x10\x03**\n\x16SearchItemVideoSubType\x12\x07\n\x03UGC\x10\x00\x12\x07\n\x03PGC\x10\x01*!\n\x12UserCallbackAction\x12\x0b\n\x07\x44ismiss\x10\x00*\x1f\n\x11UserCallbackScene\x12\n\n\x06Insert\x10\x00\x32\x97\n\n\x05Reply\x12j\n\x08MainList\x12-.bilibili.main.community.reply.v1.MainListReq\x1a/.bilibili.main.community.reply.v1.MainListReply\x12p\n\nDetailList\x12/.bilibili.main.community.reply.v1.DetailListReq\x1a\x31.bilibili.main.community.reply.v1.DetailListReply\x12p\n\nDialogList\x12/.bilibili.main.community.reply.v1.DialogListReq\x1a\x31.bilibili.main.community.reply.v1.DialogListReply\x12s\n\x0bPreviewList\x12\x30.bilibili.main.community.reply.v1.PreviewListReq\x1a\x32.bilibili.main.community.reply.v1.PreviewListReply\x12\x85\x01\n\x11SearchItemPreHook\x12\x36.bilibili.main.community.reply.v1.SearchItemPreHookReq\x1a\x38.bilibili.main.community.reply.v1.SearchItemPreHookReply\x12p\n\nSearchItem\x12/.bilibili.main.community.reply.v1.SearchItemReq\x1a\x31.bilibili.main.community.reply.v1.SearchItemReply\x12j\n\x08\x41tSearch\x12-.bilibili.main.community.reply.v1.AtSearchReq\x1a/.bilibili.main.community.reply.v1.AtSearchReply\x12m\n\tReplyInfo\x12..bilibili.main.community.reply.v1.ReplyInfoReq\x1a\x30.bilibili.main.community.reply.v1.ReplyInfoReply\x12v\n\x0cUserCallback\x12\x31.bilibili.main.community.reply.v1.UserCallbackReq\x1a\x33.bilibili.main.community.reply.v1.UserCallbackReply\x12\x81\x01\n\x10ShareRepliesInfo\x12\x35.bilibili.main.community.reply.v1.ShareRepliesInfoReq\x1a\x36.bilibili.main.community.reply.v1.ShareRepliesInfoResp\x12x\n\rSuggestEmotes\x12\x32.bilibili.main.community.reply.v1.SuggestEmotesReq\x1a\x33.bilibili.main.community.reply.v1.SuggestEmotesRespb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.main.community.reply.v1.reply_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTENT_MENBERENTRY._options = None
  _CONTENT_MENBERENTRY._serialized_options = b'8\001'
  _CONTENT_EMOTEENTRY._options = None
  _CONTENT_EMOTEENTRY._serialized_options = b'8\001'
  _CONTENT_TOPICENTRY._options = None
  _CONTENT_TOPICENTRY._serialized_options = b'8\001'
  _CONTENT_URLENTRY._options = None
  _CONTENT_URLENTRY._serialized_options = b'8\001'
  _CONTENT_ATNAMETOMIDENTRY._options = None
  _CONTENT_ATNAMETOMIDENTRY._serialized_options = b'8\001'
  _MAINLISTREPLY_CALLBACKSENTRY._options = None
  _MAINLISTREPLY_CALLBACKSENTRY._serialized_options = b'8\001'
  _DETAILLISTSCENE._serialized_start=14757
  _DETAILLISTSCENE._serialized_end=14811
  _MODE._serialized_start=14813
  _MODE._serialized_end=14888
  _SEARCHITEMTYPE._serialized_start=14890
  _SEARCHITEMTYPE._serialized_end=14964
  _SEARCHITEMVIDEOSUBTYPE._serialized_start=14966
  _SEARCHITEMVIDEOSUBTYPE._serialized_end=15008
  _USERCALLBACKACTION._serialized_start=15010
  _USERCALLBACKACTION._serialized_end=15043
  _USERCALLBACKSCENE._serialized_start=15045
  _USERCALLBACKSCENE._serialized_end=15076
  _ACTIVITY._serialized_start=109
  _ACTIVITY._serialized_end=194
  _ARTICLESEARCHITEM._serialized_start=196
  _ARTICLESEARCHITEM._serialized_end=267
  _ATGROUP._serialized_start=269
  _ATGROUP._serialized_end=375
  _ATITEM._serialized_start=377
  _ATITEM._serialized_end=470
  _ATSEARCHREPLY._serialized_start=472
  _ATSEARCHREPLY._serialized_end=546
  _ATSEARCHREQ._serialized_start=548
  _ATSEARCHREQ._serialized_end=591
  _CM._serialized_start=593
  _CM._serialized_end=643
  _CONTENT._serialized_start=646
  _CONTENT._serialized_end=1606
  _CONTENT_MENBERENTRY._serialized_start=1210
  _CONTENT_MENBERENTRY._serialized_end=1297
  _CONTENT_EMOTEENTRY._serialized_start=1299
  _CONTENT_EMOTEENTRY._serialized_end=1384
  _CONTENT_TOPICENTRY._serialized_start=1386
  _CONTENT_TOPICENTRY._serialized_end=1471
  _CONTENT_URLENTRY._serialized_start=1473
  _CONTENT_URLENTRY._serialized_end=1554
  _CONTENT_ATNAMETOMIDENTRY._serialized_start=1556
  _CONTENT_ATNAMETOMIDENTRY._serialized_end=1606
  _PICTURE._serialized_start=1608
  _PICTURE._serialized_end=1691
  _CURSORREPLY._serialized_start=1694
  _CURSORREPLY._serialized_end=1840
  _CURSORREQ._serialized_start=1842
  _CURSORREQ._serialized_end=1935
  _DETAILLISTREPLY._serialized_start=1938
  _DETAILLISTREPLY._serialized_end=2273
  _DETAILLISTREQ._serialized_start=2276
  _DETAILLISTREQ._serialized_end=2473
  _DIALOGLISTREPLY._serialized_start=2476
  _DIALOGLISTREPLY._serialized_end=2755
  _DIALOGLISTREQ._serialized_start=2758
  _DIALOGLISTREQ._serialized_end=2889
  _EFFECTS._serialized_start=2891
  _EFFECTS._serialized_end=2920
  _EMOTE._serialized_start=2923
  _EMOTE._serialized_end=3058
  _GOODSSEARCHITEM._serialized_start=3060
  _GOODSSEARCHITEM._serialized_end=3162
  _LIKEINFO._serialized_start=3165
  _LIKEINFO._serialized_end=3320
  _LIKEINFO_ITEM._serialized_start=3256
  _LIKEINFO_ITEM._serialized_end=3320
  _LOTTERY._serialized_start=3323
  _LOTTERY._serialized_end=3650
  _MAINLISTREPLY._serialized_start=3653
  _MAINLISTREPLY._serialized_end=4734
  _MAINLISTREPLY_CALLBACKSENTRY._serialized_start=4686
  _MAINLISTREPLY_CALLBACKSENTRY._serialized_end=4734
  _MAINLISTREQ._serialized_start=4737
  _MAINLISTREQ._serialized_end=4929
  _MEMBER._serialized_start=4932
  _MEMBER._serialized_end=6270
  _MEMBER_REGION._serialized_start=5860
  _MEMBER_REGION._serialized_end=6023
  _MEMBER_NFTINTERACTION._serialized_start=6026
  _MEMBER_NFTINTERACTION._serialized_end=6160
  _MEMBER_REGIONTYPE._serialized_start=6162
  _MEMBER_REGIONTYPE._serialized_end=6210
  _MEMBER_SHOWSTATUS._serialized_start=6212
  _MEMBER_SHOWSTATUS._serialized_end=6270
  _MEMBERV2._serialized_start=6273
  _MEMBERV2._serialized_end=8084
  _MEMBERV2_BASIC._serialized_start=6813
  _MEMBERV2_BASIC._serialized_end=6889
  _MEMBERV2_OFFICIAL._serialized_start=6891
  _MEMBERV2_OFFICIAL._serialized_end=6922
  _MEMBERV2_VIP._serialized_start=6925
  _MEMBERV2_VIP._serialized_end=7095
  _MEMBERV2_GARB._serialized_start=7098
  _MEMBERV2_GARB._serialized_end=7267
  _MEMBERV2_MEDAL._serialized_start=7270
  _MEMBERV2_MEDAL._serialized_end=7474
  _MEMBERV2_REGION._serialized_start=7477
  _MEMBERV2_REGION._serialized_end=7644
  _MEMBERV2_INTERACTION._serialized_start=7647
  _MEMBERV2_INTERACTION._serialized_end=7780
  _MEMBERV2_NFT._serialized_start=7782
  _MEMBERV2_NFT._serialized_end=7878
  _MEMBERV2_SENIOR._serialized_start=7880
  _MEMBERV2_SENIOR._serialized_end=7914
  _MEMBERV2_CONTRACTOR._serialized_start=7916
  _MEMBERV2_CONTRACTOR._serialized_end=7974
  _MEMBERV2_REGIONTYPE._serialized_start=6162
  _MEMBERV2_REGIONTYPE._serialized_end=6210
  _MEMBERV2_SHOWSTATUS._serialized_start=6212
  _MEMBERV2_SHOWSTATUS._serialized_end=6270
  _NOTICE._serialized_start=8086
  _NOTICE._serialized_end=8137
  _OPERATION._serialized_start=8140
  _OPERATION._serialized_end=8360
  _OPERATIONTITLE._serialized_start=8362
  _OPERATIONTITLE._serialized_end=8417
  _PGCVIDEOSEARCHITEM._serialized_start=8419
  _PGCVIDEOSEARCHITEM._serialized_end=8487
  _PREVIEWLISTREPLY._serialized_start=8490
  _PREVIEWLISTREPLY._serialized_end=8895
  _PREVIEWLISTREQ._serialized_start=8897
  _PREVIEWLISTREQ._serialized_end=9001
  _QOEINFO._serialized_start=9004
  _QOEINFO._serialized_end=9184
  _QOESCOREITEM._serialized_start=9186
  _QOESCOREITEM._serialized_end=9243
  _REPLYCARDLABEL._serialized_start=9246
  _REPLYCARDLABEL._serialized_end=9549
  _REPLYCONTROL._serialized_start=9552
  _REPLYCONTROL._serialized_end=10135
  _REPLYEXTRA._serialized_start=10137
  _REPLYEXTRA._serialized_end=10222
  _REPLYINFO._serialized_start=10225
  _REPLYINFO._serialized_end=10692
  _REPLYINFOREPLY._serialized_start=10694
  _REPLYINFOREPLY._serialized_end=10770
  _REPLYINFOREQ._serialized_start=10772
  _REPLYINFOREQ._serialized_end=10815
  _RICHTEXT._serialized_start=10817
  _RICHTEXT._serialized_end=10899
  _RICHTEXTNOTE._serialized_start=10901
  _RICHTEXTNOTE._serialized_end=10992
  _SEARCHITEM._serialized_start=10995
  _SEARCHITEM._serialized_end=11236
  _SEARCHITEMCURSORREPLY._serialized_start=11238
  _SEARCHITEMCURSORREPLY._serialized_end=11293
  _SEARCHITEMCURSORREQ._serialized_start=11295
  _SEARCHITEMCURSORREQ._serialized_end=11399
  _SEARCHITEMPREHOOKREPLY._serialized_start=11402
  _SEARCHITEMPREHOOKREPLY._serialized_end=11549
  _SEARCHITEMPREHOOKREQ._serialized_start=11551
  _SEARCHITEMPREHOOKREQ._serialized_end=11600
  _SEARCHITEMREPLY._serialized_start=11603
  _SEARCHITEMREPLY._serialized_end=11829
  _SEARCHITEMREPLYEXTRAINFO._serialized_start=11831
  _SEARCHITEMREPLYEXTRAINFO._serialized_end=11875
  _SEARCHITEMREQ._serialized_start=11878
  _SEARCHITEMREQ._serialized_end=12008
  _SHAREREPLIESINFOREQ._serialized_start=12010
  _SHAREREPLIESINFOREQ._serialized_end=12073
  _SHAREREPLIESINFORESP._serialized_start=12076
  _SHAREREPLIESINFORESP._serialized_end=12450
  _SHAREREPLIESINFORESP_SHAREEXTRA._serialized_start=12422
  _SHAREREPLIESINFORESP_SHAREEXTRA._serialized_end=12450
  _SHAREREPLYINFO._serialized_start=12453
  _SHAREREPLYINFO._serialized_end=12666
  _SHAREREPLYTOPIC._serialized_start=12668
  _SHAREREPLYTOPIC._serialized_end=12762
  _SUBJECTCONTROL._serialized_start=12765
  _SUBJECTCONTROL._serialized_end=13455
  _SUBJECTCONTROL_FILTERTAG._serialized_start=13412
  _SUBJECTCONTROL_FILTERTAG._serialized_end=13455
  _SUGGESTEMOTESREQ._serialized_start=13457
  _SUGGESTEMOTESREQ._serialized_end=13502
  _SUGGESTEMOTESRESP._serialized_start=13504
  _SUGGESTEMOTESRESP._serialized_end=13580
  _TOPIC._serialized_start=13582
  _TOPIC._serialized_end=13615
  _UGCVIDEOSEARCHITEM._serialized_start=13617
  _UGCVIDEOSEARCHITEM._serialized_end=13706
  _UPSELECTION._serialized_start=13708
  _UPSELECTION._serialized_end=13766
  _URL._serialized_start=13769
  _URL._serialized_end=14242
  _URL_EXTRA._serialized_start=14105
  _URL_EXTRA._serialized_end=14242
  _USERCALLBACKREPLY._serialized_start=14244
  _USERCALLBACKREPLY._serialized_end=14263
  _USERCALLBACKREQ._serialized_start=14266
  _USERCALLBACKREQ._serialized_end=14461
  _VIDEOSEARCHITEM._serialized_start=14464
  _VIDEOSEARCHITEM._serialized_end=14705
  _VOTE._serialized_start=14707
  _VOTE._serialized_end=14755
  _REPLY._serialized_start=15079
  _REPLY._serialized_end=16382
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/card/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.card.v1 import ad_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_ad__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/card/v1/common.proto\x12\x14\x62ilibili.app.card.v1\x1a\x1d\x62ilibili/app/card/v1/ad.proto\"\xb1\x01\n\x04\x41rgs\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\r\n\x05up_id\x18\x02 \x01(\x03\x12\x0f\n\x07up_name\x18\x03 \x01(\t\x12\x0b\n\x03rid\x18\x04 \x01(\x05\x12\r\n\x05rname\x18\x05 \x01(\t\x12\x0b\n\x03tid\x18\x06 \x01(\x03\x12\r\n\x05tname\x18\x07 \x01(\t\x12\x10\n\x08track_id\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12\x15\n\rconverge_type\x18\n \x01(\x05\x12\x0b\n\x03\x61id\x18\x0b \x01(\x03\"x\n\x06\x41vatar\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\r\n\x05\x65vent\x18\x05 \x01(\t\x12\x10\n\x08\x65vent_v2\x18\x06 \x01(\t\x12\x15\n\rdefalut_cover\x18\x07 \x01(\x05\"\x9b\x05\n\x04\x42\x61se\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x11\n\tcard_goto\x18\x02 \x01(\t\x12\x0c\n\x04goto\x18\x03 \x01(\t\x12\r\n\x05param\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x35\n\x0bthree_point\x18\x08 \x01(\x0b\x32 .bilibili.app.card.v1.ThreePoint\x12(\n\x04\x61rgs\x18\t \x01(\x0b\x32\x1a.bilibili.app.card.v1.Args\x12\x35\n\x0bplayer_args\x18\n \x01(\x0b\x32 .bilibili.app.card.v1.PlayerArgs\x12\x0b\n\x03idx\x18\x0b \x01(\x03\x12-\n\x07\x61\x64_info\x18\x0c \x01(\x0b\x32\x1c.bilibili.app.card.v1.AdInfo\x12(\n\x04mask\x18\r \x01(\x0b\x32\x1a.bilibili.app.card.v1.Mask\x12\x11\n\tfrom_type\x18\x0e \x01(\t\x12:\n\x0ethree_point_v2\x18\x0f \x03(\x0b\x32\".bilibili.app.card.v1.ThreePointV2\x12:\n\x0ethree_point_v3\x18\x10 \x03(\x0b\x32\".bilibili.app.card.v1.ThreePointV3\x12\x31\n\x0b\x64\x65sc_button\x18\x11 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Button\x12:\n\x0ethree_point_v4\x18\x12 \x01(\x0b\x32\".bilibili.app.card.v1.ThreePointV4\x12-\n\x07up_args\x18\x13 \x01(\x0b\x32\x1c.bilibili.app.card.v1.UpArgs\"\xa5\x01\n\x06\x42utton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05\x65vent\x18\x04 \x01(\t\x12\x10\n\x08selected\x18\x05 \x01(\x05\x12\x0c\n\x04type\x18\x06 \x01(\x05\x12\x10\n\x08\x65vent_v2\x18\x07 \x01(\t\x12\x30\n\x08relation\x18\x08 \x01(\x0b\x32\x1e.bilibili.app.card.v1.Relation\")\n\rDislikeReason\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\nLikeButton\x12\x0b\n\x03\x41id\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x12\n\nshow_count\x18\x03 \x01(\x08\x12\r\n\x05\x65vent\x18\x04 \x01(\t\x12\x10\n\x08selected\x18\x05 \x01(\x05\x12\x10\n\x08\x65vent_v2\x18\x06 \x01(\t\"b\n\x04Mask\x12,\n\x06\x61vatar\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12,\n\x06\x62utton\x18\x02 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Button\"\xb0\x01\n\nPlayerArgs\x12\x0f\n\x07is_live\x18\x01 \x01(\x05\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x10\n\x08sub_type\x18\x04 \x01(\x05\x12\x0f\n\x07room_id\x18\x05 \x01(\x03\x12\r\n\x05\x65p_id\x18\x07 \x01(\x03\x12\x12\n\nis_preview\x18\x08 \x01(\x05\x12\x0c\n\x04type\x18\t \x01(\t\x12\x10\n\x08\x64uration\x18\n \x01(\x03\x12\x11\n\tseason_id\x18\x0b \x01(\x03\"\xd5\x02\n\x0bReasonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x10\n\x08\x62g_color\x18\x03 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x04 \x01(\t\x12\x10\n\x08icon_url\x18\x05 \x01(\t\x12\x18\n\x10text_color_night\x18\x06 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x07 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x08 \x01(\t\x12\x16\n\x0eicon_night_url\x18\t \x01(\t\x12\x10\n\x08\x62g_style\x18\n \x01(\x05\x12\x0b\n\x03uri\x18\x0b \x01(\t\x12\x13\n\x0bicon_bg_url\x18\x0c \x01(\t\x12\r\n\x05\x65vent\x18\r \x01(\t\x12\x10\n\x08\x65vent_v2\x18\x0e \x01(\t\x12\x17\n\x0fright_icon_type\x18\x0f \x01(\x05\x12\x16\n\x0eleft_icon_type\x18\x10 \x01(\t\"B\n\x08Relation\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\"\xbb\x02\n\nSharePlane\x12\r\n\x05title\x18\x01 \x01(\t\x12\x16\n\x0eshare_subtitle\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0b\n\x03\x61id\x18\x05 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x06 \x01(\t\x12?\n\x08share_to\x18\x07 \x03(\x0b\x32-.bilibili.app.card.v1.SharePlane.ShareToEntry\x12\x0e\n\x06\x61uthor\x18\x08 \x01(\t\x12\x11\n\tauthor_id\x18\t \x01(\x03\x12\x12\n\nshort_link\x18\n \x01(\t\x12\x13\n\x0bplay_number\x18\x0b \x01(\t\x12\x11\n\tfirst_cid\x18\x0c \x01(\x03\x1a.\n\x0cShareToEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x97\x01\n\nThreePoint\x12<\n\x0f\x64islike_reasons\x18\x01 \x03(\x0b\x32#.bilibili.app.card.v1.DislikeReason\x12\x36\n\tfeedbacks\x18\x02 \x03(\x0b\x32#.bilibili.app.card.v1.DislikeReason\x12\x13\n\x0bwatch_later\x18\x03 \x01(\x05\"\x7f\n\x0cThreePointV2\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x34\n\x07reasons\x18\x03 \x03(\x0b\x32#.bilibili.app.card.v1.DislikeReason\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\x03\"\xef\x01\n\x0cThreePointV3\x12\r\n\x05title\x18\x01 \x01(\t\x12\x16\n\x0eselected_title\x18\x02 \x01(\t\x12\x10\n\x08subtitle\x18\x03 \x01(\t\x12\x34\n\x07reasons\x18\x04 \x03(\x0b\x32#.bilibili.app.card.v1.DislikeReason\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\x03\x12\x10\n\x08selected\x18\x07 \x01(\x05\x12\x0c\n\x04icon\x18\x08 \x01(\t\x12\x15\n\rselected_icon\x18\t \x01(\t\x12\x0b\n\x03url\x18\n \x01(\t\x12\x12\n\ndefault_id\x18\x0b \x01(\x05\"|\n\x0cThreePointV4\x12\x35\n\x0bshare_plane\x18\x01 \x01(\x0b\x32 .bilibili.app.card.v1.SharePlane\x12\x35\n\x0bwatch_later\x18\x02 \x01(\x0b\x32 .bilibili.app.card.v1.WatchLater\"\xb9\x01\n\x02Up\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12,\n\x06\x61vatar\x18\x04 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12\x15\n\rofficial_icon\x18\x05 \x01(\x05\x12\x31\n\x0b\x64\x65sc_button\x18\x06 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Button\x12\x13\n\x0b\x63ooperation\x18\x07 \x01(\t\"K\n\x06UpArgs\x12\r\n\x05up_id\x18\x01 \x01(\x03\x12\x0f\n\x07up_name\x18\x02 \x01(\t\x12\x0f\n\x07up_face\x18\x03 \x01(\t\x12\x10\n\x08selected\x18\x04 \x01(\x03\"\'\n\nWatchLater\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.card.v1.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SHAREPLANE_SHARETOENTRY._options = None
  _SHAREPLANE_SHARETOENTRY._serialized_options = b'8\001'
  _ARGS._serialized_start=91
  _ARGS._serialized_end=268
  _AVATAR._serialized_start=270
  _AVATAR._serialized_end=390
  _BASE._serialized_start=393
  _BASE._serialized_end=1060
  _BUTTON._serialized_start=1063
  _BUTTON._serialized_end=1228
  _DISLIKEREASON._serialized_start=1230
  _DISLIKEREASON._serialized_end=1271
  _LIKEBUTTON._serialized_start=1273
  _LIKEBUTTON._serialized_end=1384
  _MASK._serialized_start=1386
  _MASK._serialized_end=1484
  _PLAYERARGS._serialized_start=1487
  _PLAYERARGS._serialized_end=1663
  _REASONSTYLE._serialized_start=1666
  _REASONSTYLE._serialized_end=2007
  _RELATION._serialized_start=2009
  _RELATION._serialized_end=2075
  _SHAREPLANE._serialized_start=2078
  _SHAREPLANE._serialized_end=2393
  _SHAREPLANE_SHARETOENTRY._serialized_start=2347
  _SHAREPLANE_SHARETOENTRY._serialized_end=2393
  _THREEPOINT._serialized_start=2396
  _THREEPOINT._serialized_end=2547
  _THREEPOINTV2._serialized_start=2549
  _THREEPOINTV2._serialized_end=2676
  _THREEPOINTV3._serialized_start=2679
  _THREEPOINTV3._serialized_end=2918
  _THREEPOINTV4._serialized_start=2920
  _THREEPOINTV4._serialized_end=3044
  _UP._serialized_start=3047
  _UP._serialized_end=3232
  _UPARGS._serialized_start=3234
  _UPARGS._serialized_end=3309
  _WATCHLATER._serialized_start=3311
  _WATCHLATER._serialized_end=3350
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/rpc/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x62ilibili/rpc/status.proto\x12\x0c\x62ilibili.rpc\x1a\x19google/protobuf/any.proto\"N\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12%\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Anyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.rpc.status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STATUS._serialized_start=70
  _STATUS._serialized_end=148
# @@protoc_insertion_point(module_scope)
